
package com.ebay.migration;

// use java sdk to authenticate
import com.ebay.soap.eBLBaseComponents.*;
import com.ebay.sdk.*;

import java.util.Calendar;

import org.apache.axis.types.URI.MalformedURIException;
import java.rmi.RemoteException;
import java.util.Properties;
import java.text.SimpleDateFormat;
import java.io.IOException;
import java.io.FileInputStream;


/**
 * 
 * @author Suzanne Ahmed   suzanne.ahmed@ebay.com
 * 
 */

public class CallJsdk {

  public static void main(String[] args) throws MalformedURIException, RemoteException {
  	
//  Read properties file to load developer credentials
    Properties keys = new Properties();
    try {
        keys.load(new FileInputStream("keys.properties"));
    } catch (IOException e) {
        System.out.println(e);
    }
    
    // set credentials in ApiAccount
    ApiAccount account = new ApiAccount();
    account.setDeveloper( keys.getProperty("devId") );
    account.setApplication( keys.getProperty("appId") );
    account.setCertificate( keys.getProperty("certId") );
    
    // set credentials in ApiCredential
    ApiCredential credential = new ApiCredential();
    credential.setApiAccount( account );
    credential.seteBayToken( keys.getProperty("token") );
    
    // add ApiCredential to ApiContext
    ApiContext context = new ApiContext();
    context.setApiCredential(credential);
  
    // set eBay server URL to call
    context.setApiServerUrl( "https://api.sandbox.ebay.com/wsapi" );  // sandbox
    
    // set timeout in milliseconds - 3 minutes
    context.setTimeout(180000);
    
    // set wsdl version number
    context.setWSDLVersion("423");
    
    // turn on logging to standard out
    ApiLogging logging = new ApiLogging();
    logging.setEnableLogging(true);
    logging.setLogSOAPMessages(true);
    logging.setLogExceptions(true);
    context.setApiLogging(logging);
    
    
    // create ApiCall object - we'll use it to make the call
    ApiCall call = new ApiCall( context );
    
    // create soap api request and response objects
    GeteBayOfficialTimeRequestType request = new GeteBayOfficialTimeRequestType();
    AbstractResponseType response;
    
    // make the call and handle the response
    try {
    	response = call.executeByApiName("GeteBayOfficialTime", request);
    	
        // Get the ebay time
        // Result inherits from AbstractResponseType
        Calendar cal = response.getTimestamp();            // ebay time is returned in gmt 

        // Display official ebay time in gmt
        int year = cal.get(Calendar.YEAR);
        int month = cal.get(Calendar.MONTH);
        month = month + 1;   // java months go from 0-11; make human readable
        int day = cal.get(Calendar.DAY_OF_MONTH);
        int hour24 = cal.get(Calendar.HOUR_OF_DAY);
        int min = cal.get(Calendar.MINUTE);
        int sec = cal.get(Calendar.SECOND);
        System.out.println("official ebay time in gmt is: " + year + "-" + month + "-" + day + " " + hour24 + ":" + min + ":" + sec);
        
        // Convert ebay time to local time and display
        SimpleDateFormat formatter = new SimpleDateFormat("E, dd MMM yyyy HH:mm:ss Z");
        System.out.println("in your time zone " + formatter.format( cal.getTime() ));
        
    } catch (ApiException ae) {
    	System.out.println(ae);
    } catch (SdkSoapException sse) {
    	System.out.println(sse);
    } catch (SdkException se) {
    	System.out.println(se);
    }
    			
  }
 }

